@@ -31,7 +31,7 @@ Usage::
     get_transit_gateway_registrations_paginator: GetTransitGatewayRegistrationsPaginator = client.get_paginator("get_transit_gateway_registrations")
     ```
 """
-from mypy_boto3_networkmanager.client import NetworkManagerClient, NetworkManagerClient as Client
+from mypy_boto3_networkmanager.client import NetworkManagerClient
 from mypy_boto3_networkmanager.paginator import (
     DescribeGlobalNetworksPaginator,
     GetCustomerGatewayAssociationsPaginator,
@@ -42,6 +42,8 @@ from mypy_boto3_networkmanager.paginator import (
     GetTransitGatewayRegistrationsPaginator,
 )
 
+Client = NetworkManagerClient
+
 
 __all__ = (
     "Client",
